@@ -114,7 +114,7 @@ class RuleBasedDisambiguation:
         :return: Label decided for the word.
         :rtype: `tp.List[str]`
         """
-        if self.__is_main_verb(sentence[word_index + steps_forward]):
+        if word_index < len(sentence) - steps_forward and self.__is_main_verb(sentence[word_index + steps_forward]):
             return ['VERB']
         else:
             return alt_label
